@@ -626,7 +626,7 @@ void Application::readOptions()
 
         for (int hiIndex=0; hiIndex < hiList.count(); hiIndex+=2)
         {
-            Preferences::addHighlight(hiList[hiIndex], false, QString('#'+hiList[hiIndex+1]), QString(), QString(), QString(), true);
+            Preferences::addHighlight(hiList[hiIndex], false, QString('#'+hiList[hiIndex+1]), QString(), QString(), QString());
         }
 
         cgDefault.deleteEntry("Highlight");
@@ -644,8 +644,7 @@ void Application::readOptions()
                 cgHilight.readEntry("Color", QColor(Qt::black)),
                 cgHilight.readPathEntry("Sound", QString()),
                 cgHilight.readEntry("AutoText"),
-                cgHilight.readEntry("ChatWindows"),
-                cgHilight.readEntry("Notify", true)
+                cgHilight.readEntry("ChatWindows")
                 );
             i++;
         }
