@@ -51,19 +51,19 @@ StatusPanel::StatusPanel(QWidget* parent) : ChatWindow(parent)
     awayLabel=new AwayLabel(commandLineBox);
     awayLabel->hide();
 
-    statusInput=new IRCInput(commandLineBox);
+    m_inputBar=new IRCInput(commandLineBox);
 
-    getTextView()->installEventFilter(statusInput);
-    statusInput->installEventFilter(this);
+    getTextView()->installEventFilter(m_inputBar);
+    m_inputBar->installEventFilter(this);
 
-    connect(getTextView(),SIGNAL (gotFocus()),statusInput,SLOT (setFocus()) );
+    connect(getTextView(),SIGNAL (gotFocus()),m_inputBar,SLOT (setFocus()) );
 
     connect(getTextView(),SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
-    connect(getTextView(),SIGNAL (autoText(QString)),this,SLOT (sendStatusText(QString)) );
+    connect(getTextView(),SIGNAL (autoText(QString)),this,SLOT (sendText(QString)) );
 
-    connect(statusInput,SIGNAL (submit()),this,SLOT(statusTextEntered()) );
-    connect(statusInput,SIGNAL (textPasted(QString)),this,SLOT(textPasted(QString)) );
-    connect(getTextView(), SIGNAL(textPasted(bool)), statusInput, SLOT(paste(bool)));
+    connect(m_inputBar,SIGNAL (submit()),this,SLOT(statusTextEntered()) );
+    connect(m_inputBar,SIGNAL (textPasted(QString)),this,SLOT(textPasted(QString)) );
+    connect(getTextView(), SIGNAL(textPasted(bool)), m_inputBar, SLOT(paste(bool)));
 
     connect(nicknameCombobox,SIGNAL (activated(int)),this,SLOT(nicknameComboboxChanged()));
     Q_ASSERT(nicknameCombobox->lineEdit());       //it should be editable.  if we design it so it isn't, remove these lines.
@@ -89,18 +89,16 @@ void StatusPanel::setNickname(const QString& newNickname)
 
 void StatusPanel::childAdjustFocus()
 {
-    statusInput->setFocus();
+    m_inputBar->setFocus();
 }
 
-void StatusPanel::sendStatusText(const QString& sendLine)
+void StatusPanel::sendText(const QString& sendLine)
 {
     // create a work copy
     QString outputAll(sendLine);
+
     // replace aliases and wildcards
-    if(m_server->getOutputFilter()->replaceAliases(outputAll))
-    {
-        outputAll = m_server->parseWildcards(outputAll, m_server->getNickname(), QString(), QString(), QString(), QString());
-    }
+    m_server->getOutputFilter()->replaceAliases(outputAll, this);
 
     // Send all strings, one after another
     QStringList outList=outputAll.split('\n');
@@ -122,11 +120,11 @@ void StatusPanel::sendStatusText(const QString& sendLine)
 
 void StatusPanel::statusTextEntered()
 {
-    QString line = sterilizeUnicode(statusInput->toPlainText());
+    QString line = sterilizeUnicode(m_inputBar->toPlainText());
 
-    statusInput->clear();
+    m_inputBar->clear();
 
-    if (!line.isEmpty()) sendStatusText(line);
+    if (!line.isEmpty()) sendText(line);
 }
 
 void StatusPanel::textPasted(const QString& text)
@@ -140,7 +138,7 @@ void StatusPanel::textPasted(const QString& text)
             QString cChar(Preferences::self()->commandChar());
             // make sure that lines starting with command char get escaped
             if(line.startsWith(cChar)) line=cChar+line;
-            sendStatusText(line);
+            sendText(line);
         }
     }
 }
@@ -208,8 +206,6 @@ void StatusPanel::showEvent(QShowEvent*)
     }
 }
 
-QString StatusPanel::getTextInLine() { return statusInput->toPlainText(); }
-
 bool StatusPanel::canBeFrontView()        { return true; }
 bool StatusPanel::searchView()       { return true; }
 
@@ -228,7 +224,7 @@ bool StatusPanel::closeYourself(bool confirm)
     {
         result = KMessageBox::warningContinueCancel(
                 this,
-                i18n("Do you really want to close '%1'?\n\n All associated tabs will be closed as well.",getName()),
+                i18n("Do you really want to close '%1'?\n\nAll associated tabs will be closed as well.",getName()),
                 i18n("Close Tab"),
                 KStandardGuiItem::close(),
                 KStandardGuiItem::cancel(),
@@ -238,7 +234,7 @@ bool StatusPanel::closeYourself(bool confirm)
     {
         result = KMessageBox::warningContinueCancel(
             this,
-            i18n("Do you want to disconnect from '%1'?\n\n All associated tabs will be closed as well.",m_server->getServerName()),
+            i18n("Do you want to disconnect from '%1'?\n\nAll associated tabs will be closed as well.",m_server->getServerName()),
             i18n("Disconnect From Server"),
             KGuiItem(i18n("Disconnect")),
             KStandardGuiItem::cancel(),
@@ -274,7 +270,7 @@ void StatusPanel::nicknameComboboxChanged()
         m_server->queue("NICK "+newNick);
     }
     // return focus to input line
-    statusInput->setFocus();
+    m_inputBar->setFocus();
 }
 
 void StatusPanel::changeNickname(const QString& newNickname)
@@ -286,20 +282,6 @@ void StatusPanel::emitUpdateInfo()
 {
     emit updateInfo(getServer()->getDisplayName());
 }
-
-void StatusPanel::appendInputText(const QString& text, bool fromCursor)
-{
-    if (!fromCursor)
-    {
-        QTextCursor c(statusInput->textCursor());
-        c.movePosition(QTextCursor::End);
-        c.insertText(text);
-    }
-    else
-    {
-        statusInput->textCursor().insertText(text);
-    }
-}
                                                   // virtual
 void StatusPanel::setChannelEncoding(const QString& encoding)
 {
@@ -325,7 +307,7 @@ QString StatusPanel::getChannelEncodingDefaultDesc()
 //Used to disable functions when not connected
 void StatusPanel::serverOnline(bool online)
 {
-    //statusInput->setEnabled(online);
+    //m_inputBar->setEnabled(online);
     nicknameCombobox->setEnabled(online);
 }
 
